@@ -1,6 +1,6 @@
 #!/bin/bash
 # rm .git/prettygit.yml
 pip uninstall prettygit
-python ./prettygit
+python ./prettygit -h
 # python test.py
 # bash build.sh
